@@ -24,6 +24,7 @@ from sagemaker.spark import defaults
 logger = logging.getLogger(__name__)
 
 ECR_URI_TEMPLATE = "{registry}.dkr.{hostname}/{repository}"
+HUGGING_FACE_FRAMEWORK = "huggingface"
 
 
 def retrieve(
@@ -36,6 +37,7 @@ def retrieve(
     image_scope=None,
     container_version=None,
     distribution=None,
+    base_framework_version=None,
 ):
     """Retrieves the ECR URI for the Docker image matching the given arguments.
 
@@ -66,9 +68,18 @@ def retrieve(
     """
     config = _config_for_framework_and_scope(framework, image_scope, accelerator_type)
 
+    original_version = version
     version = _validate_version_and_set_if_needed(version, config, framework)
     version_config = config["versions"][_version_for_config(version, config)]
 
+    if framework == HUGGING_FACE_FRAMEWORK:
+        if version_config.get("version_aliases"):
+            full_base_framework_version = version_config["version_aliases"].get(
+                base_framework_version, base_framework_version
+            )
+        _validate_arg(full_base_framework_version, list(version_config.keys()), "base framework")
+        version_config = version_config.get(full_base_framework_version)
+
     py_version = _validate_py_version_and_set_if_needed(py_version, version_config, framework)
     version_config = version_config.get(py_version) or version_config
 
@@ -81,8 +92,16 @@ def retrieve(
         instance_type, config.get("processors") or version_config.get("processors")
     )
 
+    if framework == HUGGING_FACE_FRAMEWORK:
+        pt_or_tf_version = (
+            re.compile("^(pytorch|tensorflow)(.*)$").match(base_framework_version).group(2)
+        )
+        tag_prefix = f"{pt_or_tf_version}-transformers{original_version}"
+    else:
+        tag_prefix = version_config.get("tag_prefix", version)
+
     tag = _format_tag(
-        version_config.get("tag_prefix", version),
+        tag_prefix,
         processor,
         py_version,
         container_version,
@@ -92,8 +111,10 @@ def retrieve(
         container_versions = {
             "tensorflow-2.3-gpu-py37": "cu110-ubuntu18.04-v3",
             "tensorflow-2.3.1-gpu-py37": "cu110-ubuntu18.04",
+            "tensorflow-2.3.2-gpu-py37": "cu110-ubuntu18.04",
             "tensorflow-1.15-gpu-py37": "cu110-ubuntu18.04-v8",
             "tensorflow-1.15.4-gpu-py37": "cu110-ubuntu18.04",
+            "tensorflow-1.15.5-gpu-py37": "cu110-ubuntu18.04",
             "mxnet-1.8-gpu-py37": "cu110-ubuntu16.04-v1",
             "mxnet-1.8.0-gpu-py37": "cu110-ubuntu16.04",
             "pytorch-1.6-gpu-py36": "cu110-ubuntu18.04-v3",
@@ -125,8 +146,9 @@ def _config_for_framework_and_scope(framework, image_scope, accelerator_type=Non
         image_scope = "eia"
 
     available_scopes = config.get("scope", config.keys())
+
     if len(available_scopes) == 1:
-        if image_scope and image_scope != available_scopes[0]:
+        if image_scope and image_scope != list(available_scopes)[0]:
             logger.warning(
                 "Defaulting to only supported image scope: %s. Ignoring image scope: %s.",
                 available_scopes[0],
