@@ -651,7 +651,9 @@ class Model(object):
         job_status = self.sagemaker_session.wait_for_compilation_job(job_name)
         self.model_data = job_status["ModelArtifacts"]["S3ModelArtifacts"]
         if target_instance_family is not None:
-            if target_instance_family.startswith("ml_"):
+            if target_instance_family == "ml_eia2":
+                pass
+            elif target_instance_family.startswith("ml_"):
                 self.image_uri = self._compilation_image_uri(
                     self.sagemaker_session.boto_region_name,
                     target_instance_family,
