@@ -10,21 +10,8 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Placeholder docstring"""
+"""Classes for using TensorFlow and TensorFlow Serving with Amazon SageMaker."""
 from __future__ import absolute_import
 
-import sys
-import os
-
-# Hack to use our local copy of tensorflow_serving.apis, which contains the protobuf-generated
-# classes for tensorflow serving. Currently tensorflow_serving_api can only be pip-installed for
-# python 2.
-sys.path.append(os.path.dirname(__file__))
-
-from sagemaker.tensorflow.estimator import (  # noqa: E402, F401 # pylint: disable=wrong-import-position
-    TensorFlow,
-)
-from sagemaker.tensorflow.model import (  # noqa: E402, F401 # pylint: disable=wrong-import-position
-    TensorFlowModel,
-    TensorFlowPredictor,
-)
+from sagemaker.tensorflow.estimator import TensorFlow  # noqa: F401 (imported but unused)
+from sagemaker.tensorflow.model import TensorFlowModel, TensorFlowPredictor  # noqa: F401
